Module diff

Module diff 

Structs

Change
A single change within a file.
ChangeContext
Context lines surrounding a change for display.
FileChanges
All changes applied to a single file.
OpResult
The result of applying an operation, including all file changes.
Summary
Summary statistics for the full run.

Functions

compute_summary
Compute an aggregate summary from a slice of OpResults.