pub struct PatternRange {
pub start_pattern: String,
pub end_pattern: String,
}Expand description
A pattern-addressed region, like sed’s /start/,/end/.
Both patterns are regexes. A region opens on a line matching
start_pattern and closes on the next subsequent line matching
end_pattern (both boundary lines are inside the region; the end
pattern is never tested against the line that opened the region, so
/a/,/a/ spans from one a to the next one — sed semantics).
Multiple regions are supported; an unclosed region extends to EOF.
Fields
start_pattern: Stringend_pattern: StringTrait Implementations
Sourceimpl Clone for PatternRange
impl Clone for PatternRange
Sourcefn clone(&self) -> PatternRange
fn clone(&self) -> PatternRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatternRange
impl Debug for PatternRange
Sourceimpl<'de> Deserialize<'de> for PatternRange
impl<'de> Deserialize<'de> for PatternRange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PatternRange
Sourceimpl PartialEq for PatternRange
impl PartialEq for PatternRange
Sourcefn eq(&self, other: &PatternRange) -> bool
fn eq(&self, other: &PatternRange) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PatternRange
impl Serialize for PatternRange
impl StructuralPartialEq for PatternRange